@@ -1,8 +1,6 @@
 library(testthat)
 library(data.table)
 library(magrittr)
-library(dtplyr)
-library(dplyr)
 library(heims)
 
 test_check("heims")
